
Publishing your plugin
=======================

Plugin publishing can be done from the safety of the PIDA user interface.
First you will need to create the service directory [#]_. 
Once your plugin is created, in PIDA, select _Plugin Manager_ from tools, and
select the _Publish_ tab. Enter the directory containing the service, and your
username and password for the pida community website. You will be given a
chance to edit the service metadata in the user interface. When you are happy,
select the _Make package and upload_ button to complete the process.

.. [#] our advice is to use the tools/creator.py script 
       as outlined in the service authoring guide above).
.. note:

  The plugin will be placed on standby, and approved by one of the developers.
  Once it is approved, anyone can download it.

